Documentation
=============

This is the documentation for glowing-waffles.
This is a package for doing stellar photometry that relies on astropy.

.. toctree::
  :maxdepth: 2

  stellarphot/index.rst

.. note:: The layout of this directory is simply a suggestion.  To follow
          traditional practice, do *not* edit this page, but instead place
          all documentation for the package inside ``glowing_waffles/``.
          You can follow this practice or choose your own layout.
